@@ -21,6 +21,9 @@ class Synapse(ABC):
 
     def __init__(self, raw_request: Request) -> None:
         self.raw_request = raw_request
+        self.request = Request.parse_raw(self.raw_request)
+        self.connection = self.request.connection
+        self.request_type = self.request.type
 
     def execute(self):
         """
@@ -30,61 +33,84 @@ class Synapse(ABC):
         self.logger.info(self.raw_request)
         response = None
         try:
-            self.raw_request = Request.parse_raw(self.raw_request)
-            self.connection = self.raw_request.connection
-            self.request_type = self.raw_request.type
-
             if self.request_type == RequestType.CONNECT:
                 response = self.connect()
-                assert isinstance(response, Connection)
+                if not isinstance(response, Connection):
+                    raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.SYNAPSE_INFO:
                 response = self.synapse_info()
-                assert isinstance(response, SynapseInfo)
+                if not isinstance(response, SynapseInfo):
+                    raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.DESCRIBE:
-                self.request = DescribeRequest.parse_obj(self.raw_request.body)
+                self.request = DescribeRequest.parse_obj(self.request.body)
                 response = self.describe()
-                assert isinstance(response, list)
+                if not isinstance(response, list):
+                    raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    assert isinstance(val, Schema)
+                    if not isinstance(val, Schema):
+                        raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.READ:
-                self.request = SyncRequest.parse_obj(self.raw_request.body)
+                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.read()
-                assert isinstance(response, ReadResponse)
+                if not isinstance(response, ReadResponse):
+                    raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.GET:
-                self.request = SyncRequest.parse_obj(self.raw_request.body)
+                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.get()
-                assert isinstance(response, list)
+                if not isinstance(response, list):
+                    raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    assert isinstance(val, Record)
+                    if not isinstance(val, Record):
+                        raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.CREATE:
-                self.request = SyncRequest.parse_obj(self.raw_request.body)
+                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.create()
-                assert isinstance(response, list)
+                if not isinstance(response, list):
+                    raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    assert isinstance(val, Result)
+                    if not isinstance(val, Result):
+                        raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.UPDATE:
-                self.request = SyncRequest.parse_obj(self.raw_request.body)
+                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.update()
-                assert isinstance(response, list)
+                if not isinstance(response, list):
+                    raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    assert isinstance(val, Result)
+                    if not isinstance(val, Result):
+                        raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.DELETE:
-                self.request = SyncRequest.parse_obj(self.raw_request.body)
+                self.request = SyncRequest.parse_obj(self.request.body)
                 response = self.delete()
-                assert isinstance(response, list)
+                if not isinstance(response, list):
+                    raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    assert isinstance(val, Result)
+                    if not isinstance(val, Result):
+                        raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.EXTRACT_WEBHOOK_IDENTIFIER:
-                self.request = WebhookRequest.parse_obj(self.raw_request.body)
+                self.request = WebhookRequest.parse_obj(self.request.body)
                 response = self.extract_webhook_identifier()
-                assert isinstance(response, str)
+                if not isinstance(response, str):
+                    raise self.__prep_invalid_response_exception(response)
+
             elif self.request_type == RequestType.PROCESS_WEBHOOK:
-                self.request = WebhookRequest.parse_obj(self.raw_request.body)
+                self.request = WebhookRequest.parse_obj(self.request.body)
                 response = self.process_webhook()
-                assert isinstance(response, list)
+                if not isinstance(response, list):
+                    raise self.__prep_invalid_response_exception(response)
                 for val in response:
-                    assert isinstance(val, EventData)
+                    if not isinstance(val, EventData):
+                        raise self.__prep_invalid_response_exception(response)
+
             else:
+                self.logger.error(self.request)
                 raise Exception('Invalid synapse request {}'.format(self.request_type))
 
         except SyncariException as e:
@@ -94,7 +120,7 @@ class Synapse(ABC):
             err_msg = 'Failed to execute request {}'.format(self.request_type)
             err = Response()
             err.status_code = 400
-            err.reason = err_msg
+            err.reason = str(e)
             err.raw = str(e)
             err.url = self.connection.endpoint
             response = ErrorResponse(message=err_msg, response=err)
@@ -109,9 +135,17 @@ class Synapse(ABC):
             json_resp = response.json()
             return json_resp
         except:
-            logger.warn('Response was not serializable: {}'.format(response))
+            self.logger.warn('Response was not serializable: {}'.format(response))
             return response
 
+    def __prep_invalid_response_exception(self, response):
+        err_msg = 'Invalid response type for request {}'.format(self.request_type)
+        err = Response()
+        err.status_code = 400
+        err.reason = err_msg
+        err.raw = response
+        err.url = self.connection.endpoint
+        raise SyncariException(error_response=ErrorResponse(message=err_msg, response=err))
         
     @property
     def name(self) -> str:
