@@ -19,11 +19,10 @@ class SimpleRestSynapse(Synapse):
     """
         A simple rest synapse class that implements standard rest methods.
     """
+    rest_client = None
 
-    def __init__(self, request: Request, rest_client: SyncariRestClient, id_field: str, response_path: str) -> None:
+    def __init__(self, request: Request, id_field: str, response_path: str) -> None:
         super().__init__(request)
-        self.rest_client = None
-        self.rest_client = rest_client
         self.id_field = id_field
         self.response_path = response_path
 
@@ -61,33 +60,37 @@ class SimpleRestSynapse(Synapse):
     def process_single_row(self):
         pass
 
+    def get_rest_client(self):
+        self.rest_client = SyncariRestClient(self.connection.endpoint, {'api_token':self.connection.authConfig.accessToken})
+        return self.rest_client
+
     def __crud(self, operation):
         entity_name = self.request.entity.apiName
         super().print(self.get.__name__, self.request)
+        rest_client = self.get_rest_client() 
         eds = []
         for data in self.request.data:
             data = Record.parse_obj(data)
             resp = None
             if operation is CrudOperation.GET:
-                resp = self.rest_client.get(entity_name + "s" + "/" + data.id, params=self.rest_client.auth_config, json=data.values)
+                resp = rest_client.get(entity_name + "s" + "/" + data.id, params=rest_client.auth_config, json=data.values)
             elif operation is CrudOperation.CREATE:
-                resp = self.rest_client.post(entity_name + "s", params=self.rest_client.auth_config, json=data.values)
+                resp = rest_client.post(entity_name + "s", params=rest_client.auth_config, json=data.values)
             elif operation is CrudOperation.UPDATE:
-                resp = self.rest_client.put(entity_name + "s" + "/" + data.id, params=self.rest_client.auth_config, json=data.values)
+                resp = rest_client.put(entity_name + "s" + "/" + data.id, params=rest_client.auth_config, json=data.values)
             elif operation is CrudOperation.DELETE:
-                resp = self.rest_client.delete(entity_name + "s" + "/" + data.id, params=self.rest_client.auth_config)
+                resp = rest_client.delete(entity_name + "s" + "/" + data.id, params=rest_client.auth_config)
 
             if type(resp) is ErrorResponse:
-                eds.append(Result(id=data.id,syncariId=data.syncariEntityId,success=False,errors=[str(resp)]).json())
+                eds.append(Result(id=data.id,syncariId=data.syncariEntityId,success=False,errors=[str(resp)]))
 
             elif self.response_path in resp.json():
                 row = resp.json()[self.response_path]
                 if operation is CrudOperation.GET:
-                    eds.append(self.process_single_row(entity_name, self.request.entity, row).json())
+                    eds.append(self.process_single_row(entity_name, self.request.entity, row))
                 else:
-                    eds.append(Result(id=row[self.id_field],syncariId=data.syncariEntityId,success=True).json())
+                    eds.append(Result(id=row[self.id_field],syncariId=data.syncariEntityId,success=True))
             
-            
-        return Response(body=json.dumps(eds))
+        return eds
 
     
\ No newline at end of file
